Stan Math Library: stan/math/rev/mat/fun/typedefs.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

typedefs.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_MAT_FUN_TYPEDEFS_HPP
2 #define STAN_MATH_REV_MAT_FUN_TYPEDEFS_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/rev/core.hpp>
6
7 namespace stan {
8
9 namespace math {
10
11 typedef
12 Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>::Index
13 size_type;
14
19 typedef
20 Eigen::Matrix<var, Eigen::Dynamic, Eigen::Dynamic>
21 matrix_v;
22
27 typedef
28 Eigen::Matrix<var, Eigen::Dynamic, 1>
29 vector_v;
30
35 typedef
36 Eigen::Matrix<var, 1, Eigen::Dynamic>
37 row_vector_v;
38
39 }
40 }
41 #endif
core.hpp
stan::math::vector_v
Eigen::Matrix< var, Eigen::Dynamic, 1 > vector_v
The type of a (column) vector holding stan::math::var values.
Definition: typedefs.hpp:29
stan
Definition: log_sum_exp.hpp:8
stan::math::matrix_v
Eigen::Matrix< var, Eigen::Dynamic, Eigen::Dynamic > matrix_v
The type of a matrix holding stan::math::var values.
Definition: typedefs.hpp:21
stan::math::size_type
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic >::Index size_type
Type for sizes and indexes in an Eigen matrix with double e.
Definition: typedefs.hpp:13
Eigen.hpp
stan::math::row_vector_v
Eigen::Matrix< var, 1, Eigen::Dynamic > row_vector_v
The type of a row vector holding stan::math::var values.
Definition: typedefs.hpp:37

[ Stan Home Page ] © 2011–2016, Stan Development Team.